==> SJava_0.69-5.tar.gz: SJava/src/REmbedWin.c <==
#ifdef WIN32

#define NONAMELESSUNION
#include <windows.h>
#include <stdio.h>
#include <io.h> /* for isatty */
#include "Rversion.h"
#include "Startup.h"
#define PSIGNAL
#include "psignal.h"



extern void cmdlineoptions(int, char **);
extern void readconsolecfg();
extern int initapp(int, char **);
extern void Rf_mainloop(void);
extern int UserBreak;
extern int R_Interactive;
extern int R_HistorySize;
extern int R_RestoreHistory;
extern char *R_HistoryFile;

#ifdef R_CHARACTER_MODE
extern UImode CharacterMode;
#endif

extern char *getDLLVersion();
extern void saveConsoleTitle();

#include "Rinternals.h"

void setEnvironment();

void
winInit_R()
{
  char *argv[] = {"Rnetscape", "--no-save", "--silent"};
  int argc; 
  argc = sizeof(argv)/sizeof(argv[0]);

  setEnvironment();

#ifdef R_CHARACTER_MODE  /* Want this turned on. */
    CharacterMode = RTerm;
#endif
    /*
    if(strcmp(getDLLVersion(), getRVersion()) != 0) {
	fprintf(stderr, "Error: R.DLL version does not match\n");
	exit(1);
    }
    */

    cmdlineoptions(argc, argv);
#if 0
    mainThreadId = GetCurrentThreadId() ;
    signal(SIGBREAK, my_onintr); 
#endif
    setup_Rmainloop();
    /*    initapp(0, NULL); */
}

void
setEnvironment()
{
    int i, res, status = 0;
    char *RHome, PERL5LIB[MAX_PATH], PATH[10000], RHOME[MAX_PATH],
	*p, cmd[10000], Rversion[25];

    RHome = getenv("R_HOME");
    if(!RHome)
      RHome = getenv("RHOME");
    if(!RHome) {
      fprintf(stderr, "No R_HOME environment variable value\n");fflush(stderr);
      exit(1);
    }
    strcpy(RHOME, "R_HOME=");
    strcat(RHOME, RHome);
    for (p = RHOME; *p; p++) if (*p == '\\') *p = '/';
    putenv(RHOME);
    fprintf(stderr, "R_HOME: %s\n", RHOME);fflush(stderr);

    sprintf(Rversion, "R_VERSION=%s.%s", R_MAJOR, R_MINOR);
    putenv(Rversion);
    fprintf(stderr, "RVersion: %s\n", Rversion);fflush(stderr);
   
    putenv("R_CMD=Rcmd");
    putenv("R_UNDER_WINDOWS=1");

    strcpy(PATH, "PATH=");
    strcat(PATH, RHome); strcat(PATH, "\\bin;");
    strcat(PATH, getenv("PATH"));
    putenv(PATH);

    if( (p = getenv("TMPDIR")) && strlen(p)) {
	/* TMPDIR is already set */
    } else {
	putenv("TMPDIR=c:/TEMP");
    }

    strcpy(PERL5LIB, "PERL5LIB=");
    strcat(PERL5LIB, RHome); strcat(PERL5LIB, "\\share\\perl;");
    if( (p = getenv("PERL5LIB")) ) strcat(PERL5LIB, p);
    putenv(PERL5LIB);
}

#else


#endif

==> SJava_0.94.0.tar.gz: SJava/src/REmbedWin.c <==
#ifdef WIN32

#define NONAMELESSUNION
#include <windows.h>
#include <stdio.h>
#include <io.h> /* for isatty */
#include "Rversion.h"
#include "Startup.h"
#define PSIGNAL
#include "psignal.h"



extern void cmdlineoptions(int, char **);
extern void readconsolecfg();
extern int initapp(int, char **);
extern void Rf_mainloop(void);
extern int UserBreak;
extern int R_Interactive;
extern int R_HistorySize;
extern int R_RestoreHistory;
extern char *R_HistoryFile;

#ifdef R_CHARACTER_MODE
extern UImode CharacterMode;
#endif

extern char *getDLLVersion();
extern void saveConsoleTitle();

#include "Rinternals.h"

int setEnvironment();

void
winInit_R()
{
  char *argv[] = {"Rnetscape", "--no-save", "--silent"};
  int argc;
  argc = sizeof(argv)/sizeof(argv[0]);

  int res = setEnvironment();
  if (res != -1) {

#ifdef R_CHARACTER_MODE  /* Want this turned on. */
      CharacterMode = RTerm;
#endif
      /*
        if(strcmp(getDLLVersion(), getRVersion()) != 0) {
	REprintf("Error: R.DLL version does not match\n");
	exit(1);
        }
      */

      cmdlineoptions(argc, argv);
#if 0
      mainThreadId = GetCurrentThreadId() ;
      signal(SIGBREAK, my_onintr);
#endif
      setup_Rmainloop();
    /*    initapp(0, NULL); */
  }
}

int
setEnvironment()
{
    int i, res, status = 0;
    char *RHome, PERL5LIB[MAX_PATH], PATH[10000], RHOME[MAX_PATH],
	*p, cmd[10000], Rversion[25];

    RHome = getenv("R_HOME");
    if(!RHome)
      RHome = getenv("RHOME");
    if(!RHome) {
        REprintf("No R_HOME environment variable value\n");
        return -1;
    }
    strcpy(RHOME, "R_HOME=");
    strcat(RHOME, RHome);
    for (p = RHOME; *p; p++) if (*p == '\\') *p = '/';
    putenv(RHOME);
    REprintf("R_HOME: %s\n", RHOME);

    sprintf(Rversion, "R_VERSION=%s.%s", R_MAJOR, R_MINOR);
    putenv(Rversion);
    REprintf("RVersion: %s\n", Rversion);

    putenv("R_CMD=Rcmd");
    putenv("R_UNDER_WINDOWS=1");

    strcpy(PATH, "PATH=");
    strcat(PATH, RHome); strcat(PATH, "\\bin;");
    strcat(PATH, getenv("PATH"));
    putenv(PATH);

    if( (p = getenv("TMPDIR")) && strlen(p)) {
	/* TMPDIR is already set */
    } else {
	putenv("TMPDIR=c:/TEMP");
    }

    strcpy(PERL5LIB, "PERL5LIB=");
    strcat(PERL5LIB, RHome); strcat(PERL5LIB, "\\share\\perl;");
    if( (p = getenv("PERL5LIB")) ) strcat(PERL5LIB, p);
    putenv(PERL5LIB);
    return 0;
}

#else


#endif
